from chelydra import backup

BACKUP_FOLDER = "./backup"
SOURCE_FOLDER = "./source_folder"
TARGET_FOLDER = "./target_folder"

# Not a real test, just setting this dummy test for validatinf pytest
def test_success():
    assert 1 == 1